==> eiffelstudio-18.11.10.2592.tar: F_code/C1/yy44.c <==
/*
 * Code for class YY_BUFFER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "yy44.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {YY_BUFFER}.make */
void F65_678 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 2L));
	loc1 = F65_701(Current, loc2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R7764[Dtype(loc1)-1179])(RTCW(loc1), arg1, ((EIF_INTEGER_32) 1L));
	F1181_9453(RTCW(loc1), (EIF_CHARACTER_8) '\000', (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	F1181_9453(RTCW(loc1), (EIF_CHARACTER_8) '\000', loc2);
	F65_679(Current, loc1);
	RTLE;
}

/* {YY_BUFFER}.make_from_buffer */
void F65_679 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = F1181_9451(RTCW(arg1));
	*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 2L));
	*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) *(EIF_INTEGER_32 *)(Current + O688[dtype-64]);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_BOOLEAN *)(Current + O693[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {YY_BUFFER}.name */
EIF_REFERENCE F65_680 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) RTOSCF(705,F65_705,(Current));
}

/* {YY_BUFFER}.content */
EIF_REFERENCE F65_681 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {YY_BUFFER}.set_position */
void F65_690 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) arg1;
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) arg2;
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {YY_BUFFER}.set_index */
void F65_691 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current + O692[Dtype(Current)-64]) = (EIF_INTEGER_32) arg1;
}

/* {YY_BUFFER}.fill */
void F65_696 (EIF_REFERENCE Current)
{
	GTCX
	
	
	*(EIF_BOOLEAN *)(Current + O698[Dtype(Current)-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {YY_BUFFER}.flush */
void F65_697 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F1181_9453(RTCW(tr1), (EIF_CHARACTER_8) '\000', ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	F1181_9453(RTCW(tr1), (EIF_CHARACTER_8) '\000', ((EIF_INTEGER_32) 2L));
	*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_BOOLEAN *)(Current + O693[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	*(EIF_BOOLEAN *)(Current + O698[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {YY_BUFFER}.compact_left */
void F65_699 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_INTEGER_32 *)(Current + O687[dtype-64]);
	ti4_1 = *(EIF_INTEGER_32 *)(Current + O692[dtype-64]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) + ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc1 >= *(EIF_INTEGER_32 *)(Current + O688[dtype-64]))) {
		F65_702(Current);
	}
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) != ((EIF_INTEGER_32) 1L))) {
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(Current + O692[dtype-64]);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32, EIF_INTEGER_32)) R1060[Dtype(tr1)-105])(RTCW(tr1), ti4_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L)));
		*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) loc1;
	}
	RTLE;
}

/* {YY_BUFFER}.new_default_buffer */
EIF_REFERENCE F65_701 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1180, 0x00).id, 1180, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1181_9448(RTCW(tr1), arg1);
	RTLE;
	return (EIF_REFERENCE) tr1;
}

/* {YY_BUFFER}.resize */
void F65_702 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) == ((EIF_INTEGER_32) 0L))) {
		ti4_1 = RTOSCF(703,F65_703,(Current));
		*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) = (EIF_INTEGER_32) ti4_1;
	} else {
		(*(EIF_INTEGER_32 *)(Current + O688[dtype-64])) *= ((EIF_INTEGER_32) 2L);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = F1181_9451(RTCW(tr1));
	if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) + ((EIF_INTEGER_32) 2L)) > ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(Current + O688[dtype-64]);
		F1181_9459(RTCW(tr1), (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 2L)));
	}
	RTLE;
}

/* {YY_BUFFER}.default_capacity */
static EIF_INTEGER_32 F65_703_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEV;
	RTOSP (703);
#define Result RTOSR(703)
	Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 16384L);
	RTOSE (703);
	RTEE;
	return Result;
#undef Result
}

EIF_INTEGER_32 F65_703 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(703,F65_703_body,(Current));
}

/* {YY_BUFFER}.name_constant */

EIF_REFERENCE F65_705 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (705,RTMS_EX_H("<string>",8,1911048254));
}

void EIF_Minit44 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/yy44.c <==
/*
 * Code for class YY_BUFFER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "yy44.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {YY_BUFFER}.make */
void F65_678 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 2L));
	loc1 = F65_701(Current, loc2);
	F1181_9486(RTCW(loc1), arg1, ((EIF_INTEGER_32) 1L));
	F1181_9484(RTCW(loc1), (EIF_CHARACTER_8) '\000', (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	F1181_9484(RTCW(loc1), (EIF_CHARACTER_8) '\000', loc2);
	F65_679(Current, loc1);
	RTLE;
}

/* {YY_BUFFER}.make_from_buffer */
void F65_679 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = F1181_9482(RTCW(arg1));
	*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 2L));
	*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) *(EIF_INTEGER_32 *)(Current + O688[dtype-64]);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_BOOLEAN *)(Current + O693[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {YY_BUFFER}.name */
EIF_REFERENCE F65_680 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) RTOSCF(705,F65_705, (Current));
}

/* {YY_BUFFER}.set_position */
void F65_690 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) arg1;
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) arg2;
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {YY_BUFFER}.set_index */
void F65_691 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current + O692[Dtype(Current)-64]) = (EIF_INTEGER_32) arg1;
}

/* {YY_BUFFER}.fill */
void F65_696 (EIF_REFERENCE Current)
{
	GTCX
	
	
	*(EIF_BOOLEAN *)(Current + O698[Dtype(Current)-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {YY_BUFFER}.flush */
void F65_697 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	F1181_9484(RTCW(tr1), (EIF_CHARACTER_8) '\000', ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	F1181_9484(RTCW(tr1), (EIF_CHARACTER_8) '\000', ((EIF_INTEGER_32) 2L));
	*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O690[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O691[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current + O689[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_BOOLEAN *)(Current + O693[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	*(EIF_BOOLEAN *)(Current + O698[dtype-64]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {YY_BUFFER}.compact_left */
void F65_699 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_INTEGER_32 *)(Current + O687[dtype-64]);
	ti4_1 = *(EIF_INTEGER_32 *)(Current + O692[dtype-64]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 - ti4_1) + ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc1 >= *(EIF_INTEGER_32 *)(Current + O688[dtype-64]))) {
		F65_702(Current);
	}
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) != ((EIF_INTEGER_32) 1L))) {
		tr1 = *(EIF_REFERENCE *)(Current);
		F1181_9488(RTCW(tr1), *(EIF_INTEGER_32 *)(Current + O692[dtype-64]), ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L)));
		*(EIF_INTEGER_32 *)(Current + O692[dtype-64]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		*(EIF_INTEGER_32 *)(Current + O687[dtype-64]) = (EIF_INTEGER_32) loc1;
	}
	RTLE;
}

/* {YY_BUFFER}.new_default_buffer */
EIF_REFERENCE F65_701 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1180, 0x01).id, 1180, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1181_9479(RTCW(tr1), arg1);
	RTLE;
	return (EIF_REFERENCE) tr1;
}

/* {YY_BUFFER}.resize */
void F65_702 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) == ((EIF_INTEGER_32) 0L))) {
		ti4_1 = RTOSCF(703,F65_703, (Current));
		*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) = (EIF_INTEGER_32) ti4_1;
	} else {
		(*(EIF_INTEGER_32 *)(Current + O688[dtype-64])) *= ((EIF_INTEGER_32) 2L);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = F1181_9482(RTCW(tr1));
	if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) + ((EIF_INTEGER_32) 2L)) > ti4_1)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		F1181_9490(RTCW(tr1), (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current + O688[dtype-64]) + ((EIF_INTEGER_32) 2L)));
	}
	RTLE;
}

/* {YY_BUFFER}.default_capacity */
static EIF_INTEGER_32 F65_703_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEV;
	RTOSP (703);
#define Result RTOSR(703)
	Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 16384L);
	RTOSE (703);
	RTEE;
	return Result;
#undef Result
}

EIF_INTEGER_32 F65_703 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(703,F65_703_body,(Current));
}

/* {YY_BUFFER}.name_constant */

EIF_REFERENCE F65_705 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (705,RTMS_EX_H("<string>",8,1911048254));
}

void EIF_Minit44 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
